#!/usr/bin/env python

# Copyright 2016 neurodata (http://neurodata.io/)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import os, sys
import sys

def mkdir(dirname):
    dirname = os.path.abspath(dirname)
    try:
        if not os.path.exists(dirname):
            os.makedirs(dirname)
        else:
            print(("[WARNING]: Dir: '{}' exists. Files will be overwritten!".\
                    format(dirname)))
    except Exception as msg:
        sys.stderr.write("Failure to make dir: '{}'.\nERROR msg: {}\n".format(
                dirname, msg))

if __name__ == "__main__":
    mkdir(sys.argv[1])
